# run_tests_report.html

Report generated on 11-Nov-2022 at 11:57:54 by pytest-html v3.2.0

## Environment

JAVA_HOME | /Library/Java/JavaVirtualMachines/adoptopenjdk-8.jdk/Contents/Home
Packages | {"pluggy": "1.0.0", "pytest": "7.2.0"}
Platform | macOS-10.16-x86_64-i386-64bit
Plugins | {"html": "3.2.0", "metadata": "2.0.4"}
Python | 3.10.6

## Summary

7 tests ran in 194.73 seconds.

(Un)check the boxes to filter the results.

5 passed, 0 skipped, 2 failed, 0 errors, 0 expected failures, 0 unexpected passes

## Results

Result | Test | Duration | Links
--- | --- | --- | ---
No results found. Try to check the filters
Failed | tests/databricks/test_basic.py::test_import_run | 22.63 |
No log output captured.
Failed | tests/databricks/test_basic.py::test_import_experiment_job | 22.67 |
No log output captured.
Passed | tests/databricks/test_basic.py::test_train_model | 21.74 |
No log output captured.
Passed | tests/databricks/test_basic.py::test_export_run | 22.95 |
No log output captured.
Passed | tests/databricks/test_basic.py::test_export_experiment_job | 24.38 |
No log output captured.
Passed | tests/databricks/test_basic.py::test_export_model | 26.08 |
No log output captured.
Passed | tests/databricks/test_basic.py::test_import_model_job | 42.22 |
No log output captured.